Django React Example
====================

Combine [Django](https://www.djangoproject.com/) and [React](https://facebook.github.io/react/).
Based on the article [Using Webpack transparently with Django](http://owaislone.org/blog/webpack-plus-reactjs-and-django/) by Owais Lone.

```
slate install django-react -name projectname
cd projectname/
    $ node server
    $ python manage.py runserver
```

Then modify `projectname/assets/js/app.jsx` to see instant changes in the browser.
